==> haskell-authenticate-1.3.5.2-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-4LjzG7ZDdiA8ZzS62MpKkY
key:                  authenticate-1.3.5.2-4LjzG7ZDdiA8ZzS62MpKkY
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  43aa3e2292d493cd699dd1c410efa6f1
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-4LjzG7ZDdiA8ZzS62MpKkY
depends:
    aeson-2.1.2.1-6jLf9XnWqJCFwZgyNgcXK5
    attoparsec-0.14.4-2y9eL1gxaFn1uCSGoZSkZz
    attoparsec-aeson-2.1.0.0-2ZYWSTdaa7z36CzR0WO7EX base-4.17.2.1
    blaze-builder-0.4.3-7r9do9coum54RrdacWKvDM bytestring-0.11.5.3
    case-insensitive-1.2.1.0-7gqgHDj4ifWAUMF7u0wWwn
    conduit-1.3.6.1-D5gtRvoNCm9CE8oOCirzgp containers-0.6.7
    html-conduit-1.3.2.2-J6tdrw0pmBuAgVvdPABDXN
    http-conduit-2.3.9.1-IP0K1a0KUSn2hcKLCls7Lr
    http-types-0.12.4-5kSnAXEr074KLJnh9ObNlR
    network-uri-2.6.4.2-Ezz3DgCiNVkB3lRSna1Fn6
    resourcet-1.2.6-HE3LPlgg2aD9KCPumUFvOx text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-C8J7H3CMcSh2WWoYFsvixL
    xml-conduit-1.9.1.4-3iMsbkaVWdj82Er1gxwGTR

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.5.2-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-3jwLwy0cE13Ex0u3xeQAvT
key:                  authenticate-1.3.5.2-3jwLwy0cE13Ex0u3xeQAvT
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  b493bd22e26a6879e0260481ba84a2a3
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-3jwLwy0cE13Ex0u3xeQAvT
depends:
    aeson-2.1.2.1-I3cDhpx2rWKJLPqMhNImsD
    attoparsec-0.14.4-BMIhC2LZoSCDLMWwXrs2Kd
    attoparsec-aeson-2.1.0.0-3RtUy7Y2igCIioLy8KS67s base-4.17.2.1
    blaze-builder-0.4.3-HjpA4ivVlJH8YxNFjqvR4Z bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4L9O7i2dYOAKEL3KQ9PGzi
    conduit-1.3.6.1-BGhD0oLI63jJc3bUabzWSG containers-0.6.7
    html-conduit-1.3.2.2-y9WgJR1n7REEpbGZeaZFr
    http-conduit-2.3.9.1-8XoAICSqxiEEJ2eC0PpMr1
    http-types-0.12.4-Jqk2Jx5UWUVCRsxSGHbgCJ
    network-uri-2.6.4.2-2wn7iZJrXjeInsr3q1MEy6
    resourcet-1.2.6-4MLLOrswxN1HrnLnm0g3Xb text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2ikAr0D5DLKB57N2l8lLdR
    xml-conduit-1.9.1.4-6P6ZL9UUwi61SZLT4nio6s

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
